###########################################################################
#
# win32 makefile -- src/colservr
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the
# University of Waikato, New Zealand.
#
# Copyright (C) 1999-2008  The New Zealand Digital Library Project
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################

GSDL_DIR = ..\..
INDEXERS_DIR = $(GSDL_DIR)\indexers


GSDL_VC4 = 0
DLL = 0
DLLDEBUG = 0
STLPATH = "$(GSDL_DIR)\packages\windows\stlport\stlport"


!IF $(GSDL_VC4)
CPPFLAGS = -GX
!ELSE
CPPFLAGS = -EHsc
!ENDIF

!IF $(DLL)
CPPFLAGS = $(CPPFLAGS) -MD
!ELSE
!IF ($(DLLDEBUG))
CPPFLAGS = $(CPPFLAGS) -MDd
!ENDIF
!ENDIF


AR = lib
CC = cl
DEFS = -D__WIN32__ -DHAVE_CONFIG_H -DPARADOCNUM -D_LITTLE_ENDIAN -DSHORT_SUFFIX -DXML_STATIC -D_CRT_SECURE_NO_DEPRECATE
# Do NOT add the "recpt" directory here: the colserver should be independent of the receptionist!
INCLUDES = -I"$(GSDL_DIR)" -I"$(GSDL_DIR)\lib" \
	-I"$(INDEXERS_DIR)\mg" -I"$(INDEXERS_DIR)\mg\lib" -I"$(INDEXERS_DIR)\mg\src\text" \
	-I"$(INDEXERS_DIR)\mgpp\lib" -I"$(INDEXERS_DIR)\mgpp\text" \
	-I"$(GSDL_DIR)\packages\windows\expat\expat" -I"$(GSDL_DIR)\packages\windows\gdbm\gdbm"

!IF $(GSDL_VC4)
DEFS=$(DEFS) -DGSDL_NAMESPACE_BROKEN -DGSDL_USE_IOS_H -D__STL_NO_NEW_IOSTREAMS
INCLUDES = $(INCLUDES) -I$(STLPATH)
!ENDIF


COMPILE = $(CC) -nologo -c $(CPPFLAGS) $(DEFS) $(INCLUDES)


.SUFFIXES:
.SUFFIXES: .c .obj
.c.obj:
	$(COMPILE) $<

.SUFFIXES: .cpp .obj
.cpp.obj:
	$(COMPILE) $< 


SOURCES = \
        browsefilter.cpp \
	collectserver.cpp \
	collectset.cpp \
        colservrconfig.cpp \
	comtypes.cpp \
	expat_document.cpp \
	expat_resultset.cpp \
	filter.cpp \
	gdbmsource.cpp \
	lucenegdbmsource.cpp \
	lucenequeryfilter.cpp \
	lucenesearch.cpp \
	maptools.cpp \
	mggdbmsource.cpp \
	mgq.c \
	mgqueryfilter.cpp \
	mgsearch.cpp \
	mgppqueryfilter.cpp \
	mgppsearch.cpp \
	phrasequeryfilter.cpp \
	phrasesearch.cpp \
	querycache.cpp \
	queryfilter.cpp \
	queryinfo.cpp \
	search.cpp \
	source.cpp

OBJECTS = \
        browsefilter.obj \
	collectserver.obj \
	collectset.obj \
        colservrconfig.obj \
	comtypes.obj \
	expat_document.obj \
	expat_resultset.obj \
	filter.obj \
	gdbmsource.obj \
	lucenegdbmsource.obj \
	lucenequeryfilter.obj \
	lucenesearch.obj \
	maptools.obj \
	mggdbmsource.obj \
	mgq.obj \
	mgqueryfilter.obj \
	mgsearch.obj \
	mgppqueryfilter.obj \
	mgppsearch.obj \
	phrasequeryfilter.obj \
	phrasesearch.obj \
	querycache.obj \
	queryfilter.obj \
	queryinfo.obj \
	search.obj \
	source.obj

LIBRARY = gsdlcolservr.lib	


gsdlcolservr.lib: $(OBJECTS) 
	if EXIST gsdlcolservr.lib del gsdlcolservr.lib
	$(AR) -nologo /out:gsdlcolservr.lib $(OBJECTS)

all: $(LIBRARY)

install: $(LIBRARY)

clean:
	del *.obj
	del gsdlcolservr.lib
